@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def cancelPending(vmanage, processId):
     """
     Bulk cancel task status
@@ -14,8 +11,8 @@ def cancelPending(vmanage, processId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/status/cancel/{processId}"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint)
+    endpoint = f"dataservice/device/action/status/cancel/{processId}"
+    response = vmanage.apiCall("POST", endpoint)
     return response
 
 def cleanStatus(vmanage, cleanStatus):
@@ -31,8 +28,8 @@ def cleanStatus(vmanage, cleanStatus):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/status/clean?cleanStatus={cleanStatus}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/status/clean?cleanStatus={cleanStatus}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def deleteStatus(vmanage, processId):
@@ -48,8 +45,8 @@ def deleteStatus(vmanage, processId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/status/clear?processId={processId}"
-    response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint)
+    endpoint = f"dataservice/device/action/status/clear?processId={processId}"
+    response = vmanage.apiCall("DELETE", endpoint)
     return response
 
 def findRunning(vmanage):
@@ -64,8 +61,8 @@ def findRunning(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/status/tasks"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/status/tasks"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getActiveCount(vmanage):
@@ -80,8 +77,8 @@ def getActiveCount(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/status/tasks/activeCount"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/status/tasks/activeCount"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getCleanStatus(vmanage, processId):
@@ -97,8 +94,8 @@ def getCleanStatus(vmanage, processId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/status/tasks/clean?processId={processId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/status/tasks/clean?processId={processId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def findStatus(vmanage, actionName):
@@ -114,6 +111,6 @@ def findStatus(vmanage, actionName):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/status/{actionName}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/status/{actionName}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
