@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getGlobal(vmanage, templateId):
     """
     Get global template
@@ -14,8 +11,8 @@ def getGlobal(vmanage, templateId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/networkdesign/global/template/{templateId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/networkdesign/global/template/{templateId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def editGlobal(vmanage, globaltemplate, templateId):
@@ -32,8 +29,8 @@ def editGlobal(vmanage, globaltemplate, templateId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/networkdesign/global/template/{templateId}"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, globaltemplate)
+    endpoint = f"dataservice/networkdesign/global/template/{templateId}"
+    response = vmanage.apiCall("PUT", endpoint, globaltemplate)
     return response
 
 def getFeatureTempList(vmanage):
@@ -48,8 +45,8 @@ def getFeatureTempList(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/networkdesign/profile/feature"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/networkdesign/profile/feature"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getProfileList(vmanage):
@@ -64,8 +61,8 @@ def getProfileList(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/networkdesign/profile/template"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/networkdesign/profile/template"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getDeviceProfile(vmanage, templateId):
@@ -81,8 +78,8 @@ def getDeviceProfile(vmanage, templateId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/networkdesign/profile/template/{templateId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/networkdesign/profile/template/{templateId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def editDeviceProfile(vmanage, globaltemplate, templateId):
@@ -99,6 +96,6 @@ def editDeviceProfile(vmanage, globaltemplate, templateId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/networkdesign/profile/template/{templateId}"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, globaltemplate)
+    endpoint = f"dataservice/networkdesign/profile/template/{templateId}"
+    response = vmanage.apiCall("PUT", endpoint, globaltemplate)
     return response
