@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getList(vmanage, deviceId):
     """
     Get feature lists from device (Real Time)
@@ -14,8 +11,8 @@ def getList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/featurelist?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/featurelist?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSyncedList(vmanage, deviceId):
     """
@@ -30,6 +27,6 @@ def getSyncedList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/featurelist/synced?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/featurelist/synced?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
