@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def createReplicatorList(vmanage, deviceId):
     """
     Get replicator list from device
@@ -14,8 +11,8 @@ def createReplicatorList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/multicast/replicator?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/multicast/replicator?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def createRpfList(vmanage, deviceId):
     """
@@ -30,8 +27,8 @@ def createRpfList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/multicast/rpf?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/multicast/rpf?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def createTopologyList(vmanage, deviceId):
     """
@@ -46,8 +43,8 @@ def createTopologyList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/multicast/topology?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/multicast/topology?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def createPimTunnelList(vmanage, deviceId):
     """
@@ -62,6 +59,6 @@ def createPimTunnelList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/multicast/tunnel?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/multicast/tunnel?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
