@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getCloudConnector(vmanage):
     """
     Get SD_AVC Cloud Connector Config
@@ -13,8 +10,8 @@ def getCloudConnector(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/sdavc/cloudconnector"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/sdavc/cloudconnector"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def disableCloudConnector(vmanage, payload):
     """
@@ -29,8 +26,8 @@ def disableCloudConnector(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/sdavc/cloudconnector"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, payload)
+    endpoint = f"dataservice/sdavc/cloudconnector"
+    response = vmanage.apiCall("PUT", endpoint, payload)
     return response
 def enableCloudConnector(vmanage, payload):
     """
@@ -45,8 +42,8 @@ def enableCloudConnector(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/sdavc/cloudconnector"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/sdavc/cloudconnector"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 def getCloudConnectorStatus(vmanage):
     """
@@ -60,6 +57,6 @@ def getCloudConnectorStatus(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/sdavc/cloudconnector/status"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/sdavc/cloudconnector/status"
+    response = vmanage.apiCall("GET", endpoint)
     return response
