@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getDBSchema(vmanage):
     """
     Get the current database schema
@@ -13,8 +10,8 @@ def getDBSchema(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/diagnostics/dbschema"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/diagnostics/dbschema"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getThreadPools(vmanage):
     """
@@ -28,8 +25,8 @@ def getThreadPools(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/diagnostics/threadpools"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/diagnostics/threadpools"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getStatDataRawData(vmanage, query):
     """
@@ -44,8 +41,8 @@ def getStatDataRawData(vmanage, query):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/statistics/speedtest?query={query}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/statistics/speedtest?query={query}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getStatsRawData(vmanage, query):
     """
@@ -60,8 +57,8 @@ def getStatsRawData(vmanage, query):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/statistics/speedtest"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, query)
+    endpoint = f"dataservice/statistics/speedtest"
+    response = vmanage.apiCall("POST", endpoint, query)
     return response
 def getAggregationDataByQuery(vmanage, query):
     """
@@ -76,8 +73,8 @@ def getAggregationDataByQuery(vmanage, query):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/statistics/speedtest/aggregation?query={query}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/statistics/speedtest/aggregation?query={query}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getPostAggregationDataByQuery(vmanage, query):
     """
@@ -92,8 +89,8 @@ def getPostAggregationDataByQuery(vmanage, query):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/statistics/speedtest/aggregation"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, query)
+    endpoint = f"dataservice/statistics/speedtest/aggregation"
+    response = vmanage.apiCall("POST", endpoint, query)
     return response
 def getPostAggregationAppDataByQuery(vmanage, query):
     """
@@ -108,8 +105,8 @@ def getPostAggregationAppDataByQuery(vmanage, query):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/statistics/speedtest/app-agg/aggregation"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, query)
+    endpoint = f"dataservice/statistics/speedtest/app-agg/aggregation"
+    response = vmanage.apiCall("POST", endpoint, query)
     return response
 def getStatDataRawDataAsCSV(vmanage, query):
     """
@@ -124,8 +121,8 @@ def getStatDataRawDataAsCSV(vmanage, query):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/statistics/speedtest/csv?query={query}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/statistics/speedtest/csv?query={query}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getCount(vmanage, query):
     """
@@ -140,8 +137,8 @@ def getCount(vmanage, query):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/statistics/speedtest/doccount?query={query}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/statistics/speedtest/doccount?query={query}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getCountPost(vmanage, query):
     """
@@ -156,8 +153,8 @@ def getCountPost(vmanage, query):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/statistics/speedtest/doccount"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, query)
+    endpoint = f"dataservice/statistics/speedtest/doccount"
+    response = vmanage.apiCall("POST", endpoint, query)
     return response
 def getStatDataFields(vmanage):
     """
@@ -171,8 +168,8 @@ def getStatDataFields(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/statistics/speedtest/fields"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/statistics/speedtest/fields"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getStatBulkRawData(vmanage, query, scrollId, count):
     """
@@ -189,8 +186,8 @@ def getStatBulkRawData(vmanage, query, scrollId, count):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/statistics/speedtest/page?query={query}&scrollId={scrollId}&count={count}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/statistics/speedtest/page?query={query}&scrollId={scrollId}&count={count}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getPostStatBulkRawData(vmanage, query, scrollId, count):
     """
@@ -207,8 +204,8 @@ def getPostStatBulkRawData(vmanage, query, scrollId, count):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/statistics/speedtest/page?scrollId={scrollId}&count={count}"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, query)
+    endpoint = f"dataservice/statistics/speedtest/page?scrollId={scrollId}&count={count}"
+    response = vmanage.apiCall("POST", endpoint, query)
     return response
 def getStatQueryFields(vmanage):
     """
@@ -222,8 +219,8 @@ def getStatQueryFields(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/statistics/speedtest/query/fields"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/statistics/speedtest/query/fields"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSessionInfoCapture(vmanage, payload):
     """
@@ -238,8 +235,8 @@ def getSessionInfoCapture(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/capture"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/stream/device/capture"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 def disablePacketCaptureSession(vmanage, sessionId):
     """
@@ -254,8 +251,8 @@ def disablePacketCaptureSession(vmanage, sessionId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/capture/disable/{sessionId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/capture/disable/{sessionId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def downloadFile(vmanage, sessionId):
     """
@@ -270,8 +267,8 @@ def downloadFile(vmanage, sessionId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/capture/download/{sessionId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/capture/download/{sessionId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def forceStopPcapSession(vmanage, sessionId):
     """
@@ -286,8 +283,8 @@ def forceStopPcapSession(vmanage, sessionId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/capture/forcedisbale/{sessionId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/capture/forcedisbale/{sessionId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def startPcapSession(vmanage, sessionId):
     """
@@ -302,8 +299,8 @@ def startPcapSession(vmanage, sessionId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/capture/start/{sessionId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/capture/start/{sessionId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getFileDownloadStatus(vmanage, sessionId):
     """
@@ -318,8 +315,8 @@ def getFileDownloadStatus(vmanage, sessionId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/capture/status/{sessionId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/capture/status/{sessionId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def stopPcapSession(vmanage, sessionId):
     """
@@ -334,8 +331,8 @@ def stopPcapSession(vmanage, sessionId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/capture/stop/{sessionId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/capture/stop/{sessionId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def formPostPacketCapture(vmanage, deviceUUID, sessionId):
     """
@@ -351,8 +348,8 @@ def formPostPacketCapture(vmanage, deviceUUID, sessionId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/capture/{deviceUUID}/{sessionId}"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint)
+    endpoint = f"dataservice/stream/device/capture/{deviceUUID}/{sessionId}"
+    response = vmanage.apiCall("POST", endpoint)
     return response
 def getSessionInfoLog(vmanage, payload):
     """
@@ -367,8 +364,8 @@ def getSessionInfoLog(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/log"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/stream/device/log"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 def disableDeviceLog(vmanage, sessionId):
     """
@@ -383,8 +380,8 @@ def disableDeviceLog(vmanage, sessionId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/log/disable/{sessionId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/log/disable/{sessionId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def downloadDebugLog(vmanage, sessionId):
     """
@@ -399,8 +396,8 @@ def downloadDebugLog(vmanage, sessionId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/log/download/{sessionId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/log/download/{sessionId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def renewSessionInfo(vmanage, sessionId):
     """
@@ -415,8 +412,8 @@ def renewSessionInfo(vmanage, sessionId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/log/renew/{sessionId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/log/renew/{sessionId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def searchDeviceLog(vmanage, payload, sessionId):
     """
@@ -432,8 +429,8 @@ def searchDeviceLog(vmanage, payload, sessionId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/log/search/{sessionId}"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/stream/device/log/search/{sessionId}"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 def getSessions(vmanage):
     """
@@ -447,8 +444,8 @@ def getSessions(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/log/sessions"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/log/sessions"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def clearSession(vmanage, sessionId):
     """
@@ -463,8 +460,8 @@ def clearSession(vmanage, sessionId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/log/sessions/clear/{sessionId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/log/sessions/clear/{sessionId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getLogType(vmanage, uuid):
     """
@@ -479,8 +476,8 @@ def getLogType(vmanage, uuid):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/log/type?uuid={uuid}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/log/type?uuid={uuid}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def streamLog(vmanage, payload, logType, deviceUUID, sessionId):
     """
@@ -498,8 +495,8 @@ def streamLog(vmanage, payload, logType, deviceUUID, sessionId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/log/{logType}/{deviceUUID}/{sessionId}"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/stream/device/log/{logType}/{deviceUUID}/{sessionId}"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 def getDeviceLog(vmanage, sessionId, logId):
     """
@@ -515,8 +512,8 @@ def getDeviceLog(vmanage, sessionId, logId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/log/{sessionId}?logId={logId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/log/{sessionId}?logId={logId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getStatDataRawData(vmanage, query):
     """
@@ -531,8 +528,8 @@ def getStatDataRawData(vmanage, query):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi?query={query}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/nwpi?query={query}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getStatsRawData(vmanage, query):
     """
@@ -547,8 +544,8 @@ def getStatsRawData(vmanage, query):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, query)
+    endpoint = f"dataservice/stream/device/nwpi"
+    response = vmanage.apiCall("POST", endpoint, query)
     return response
 def getAggregationDataByQuery(vmanage, query):
     """
@@ -563,8 +560,8 @@ def getAggregationDataByQuery(vmanage, query):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/aggregation?query={query}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/nwpi/aggregation?query={query}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getPostAggregationDataByQuery(vmanage, query):
     """
@@ -579,8 +576,8 @@ def getPostAggregationDataByQuery(vmanage, query):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/aggregation"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, query)
+    endpoint = f"dataservice/stream/device/nwpi/aggregation"
+    response = vmanage.apiCall("POST", endpoint, query)
     return response
 def getPostAggregationAppDataByQuery(vmanage, query):
     """
@@ -595,8 +592,8 @@ def getPostAggregationAppDataByQuery(vmanage, query):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/app-agg/aggregation"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, query)
+    endpoint = f"dataservice/stream/device/nwpi/app-agg/aggregation"
+    response = vmanage.apiCall("POST", endpoint, query)
     return response
 def getConcurrentData(vmanage, traceId, timestamp):
     """
@@ -612,8 +609,8 @@ def getConcurrentData(vmanage, traceId, timestamp):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/concurrentData?traceId={traceId}&timestamp={timestamp}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/nwpi/concurrentData?traceId={traceId}&timestamp={timestamp}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getConcurrentDomainData(vmanage, traceId, timestamp):
     """
@@ -629,8 +626,8 @@ def getConcurrentDomainData(vmanage, traceId, timestamp):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/concurrentDomainData?traceId={traceId}&timestamp={timestamp}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/nwpi/concurrentDomainData?traceId={traceId}&timestamp={timestamp}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getStatDataRawDataAsCSV(vmanage, query):
     """
@@ -645,8 +642,8 @@ def getStatDataRawDataAsCSV(vmanage, query):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/csv?query={query}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/nwpi/csv?query={query}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getCount(vmanage, query):
     """
@@ -661,8 +658,8 @@ def getCount(vmanage, query):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/doccount?query={query}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/nwpi/doccount?query={query}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getCountPost(vmanage, query):
     """
@@ -677,8 +674,8 @@ def getCountPost(vmanage, query):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/doccount"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, query)
+    endpoint = f"dataservice/stream/device/nwpi/doccount"
+    response = vmanage.apiCall("POST", endpoint, query)
     return response
 def getDomainMetric(vmanage, traceId, timestamp, domain, firstTimestamp, lastTimestamp):
     """
@@ -697,8 +694,8 @@ def getDomainMetric(vmanage, traceId, timestamp, domain, firstTimestamp, lastTim
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/domainMetric?traceId={traceId}&timestamp={timestamp}&domain={domain}&firstTimestamp={firstTimestamp}&lastTimestamp={lastTimestamp}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/nwpi/domainMetric?traceId={traceId}&timestamp={timestamp}&domain={domain}&firstTimestamp={firstTimestamp}&lastTimestamp={lastTimestamp}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getStatDataFields(vmanage):
     """
@@ -712,8 +709,8 @@ def getStatDataFields(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/fields"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/nwpi/fields"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getFinalizedData(vmanage, traceId, timestamp):
     """
@@ -729,8 +726,8 @@ def getFinalizedData(vmanage, traceId, timestamp):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/finalizedData?traceId={traceId}&timestamp={timestamp}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/nwpi/finalizedData?traceId={traceId}&timestamp={timestamp}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getFinalizedDomainData(vmanage, traceId, timestamp):
     """
@@ -746,8 +743,8 @@ def getFinalizedDomainData(vmanage, traceId, timestamp):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/finalizedDomainData?traceId={traceId}&timestamp={timestamp}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/nwpi/finalizedDomainData?traceId={traceId}&timestamp={timestamp}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getFlowDetail(vmanage, traceId, timestamp, flowId):
     """
@@ -764,8 +761,8 @@ def getFlowDetail(vmanage, traceId, timestamp, flowId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/flowDetail?traceId={traceId}&timestamp={timestamp}&flowId={flowId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/nwpi/flowDetail?traceId={traceId}&timestamp={timestamp}&flowId={flowId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getFlowMetric(vmanage, traceId, timestamp, flowId, firstTimestamp, lastTimestamp):
     """
@@ -784,8 +781,8 @@ def getFlowMetric(vmanage, traceId, timestamp, flowId, firstTimestamp, lastTimes
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/flowMetric?traceId={traceId}&timestamp={timestamp}&flowId={flowId}&firstTimestamp={firstTimestamp}&lastTimestamp={lastTimestamp}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/nwpi/flowMetric?traceId={traceId}&timestamp={timestamp}&flowId={flowId}&firstTimestamp={firstTimestamp}&lastTimestamp={lastTimestamp}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getMonitorState(vmanage, traceId, state):
     """
@@ -801,8 +798,8 @@ def getMonitorState(vmanage, traceId, state):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/getMonitorState?traceId={traceId}&state={state}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/nwpi/getMonitorState?traceId={traceId}&state={state}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def monitorStart(vmanage, payload):
     """
@@ -817,8 +814,8 @@ def monitorStart(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/monitor/start"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/stream/device/nwpi/monitor/start"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 def monitorStop(vmanage, payload):
     """
@@ -833,8 +830,8 @@ def monitorStop(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/monitor/stop"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/stream/device/nwpi/monitor/stop"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 def getNwpiDscp(vmanage):
     """
@@ -848,8 +845,8 @@ def getNwpiDscp(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/nwpiDSCP"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/nwpi/nwpiDSCP"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getNwpiNbarAppGroup(vmanage):
     """
@@ -863,8 +860,8 @@ def getNwpiNbarAppGroup(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/nwpiNbarAppGroup"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/nwpi/nwpiNbarAppGroup"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getNwpiProtocol(vmanage):
     """
@@ -878,8 +875,8 @@ def getNwpiProtocol(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/nwpiProtocol"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/nwpi/nwpiProtocol"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getPacketFeatures(vmanage, traceId, timestamp, flowId):
     """
@@ -896,8 +893,8 @@ def getPacketFeatures(vmanage, traceId, timestamp, flowId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/packetFeatures?traceId={traceId}&timestamp={timestamp}&flowId={flowId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/nwpi/packetFeatures?traceId={traceId}&timestamp={timestamp}&flowId={flowId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getStatBulkRawData(vmanage, query, scrollId, count):
     """
@@ -914,8 +911,8 @@ def getStatBulkRawData(vmanage, query, scrollId, count):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/page?query={query}&scrollId={scrollId}&count={count}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/nwpi/page?query={query}&scrollId={scrollId}&count={count}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getPostStatBulkRawData(vmanage, query, scrollId, count):
     """
@@ -932,8 +929,8 @@ def getPostStatBulkRawData(vmanage, query, scrollId, count):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/page?scrollId={scrollId}&count={count}"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, query)
+    endpoint = f"dataservice/stream/device/nwpi/page?scrollId={scrollId}&count={count}"
+    response = vmanage.apiCall("POST", endpoint, query)
     return response
 def getStatQueryFields(vmanage):
     """
@@ -947,8 +944,8 @@ def getStatQueryFields(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/query/fields"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/nwpi/query/fields"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def traceDelete(vmanage, traceId, timestamp):
     """
@@ -964,8 +961,8 @@ def traceDelete(vmanage, traceId, timestamp):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/trace/delete?traceId={traceId}&timestamp={timestamp}"
-    response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint)
+    endpoint = f"dataservice/stream/device/nwpi/trace/delete?traceId={traceId}&timestamp={timestamp}"
+    response = vmanage.apiCall("DELETE", endpoint)
     return response
 def traceStart(vmanage, payload):
     """
@@ -980,8 +977,8 @@ def traceStart(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/trace/start"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/stream/device/nwpi/trace/start"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 def traceStop(vmanage, traceId):
     """
@@ -996,8 +993,8 @@ def traceStop(vmanage, traceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/trace/stop/{traceId}"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint)
+    endpoint = f"dataservice/stream/device/nwpi/trace/stop/{traceId}"
+    response = vmanage.apiCall("POST", endpoint)
     return response
 def traceFinFlowWithQuery(vmanage, traceId, timestamp, query):
     """
@@ -1014,8 +1011,8 @@ def traceFinFlowWithQuery(vmanage, traceId, timestamp, query):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/traceFinFlowWithQuery?traceId={traceId}&timestamp={timestamp}&query={query}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/nwpi/traceFinFlowWithQuery?traceId={traceId}&timestamp={timestamp}&query={query}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getTraceFlow(vmanage, traceId, timestamp, state):
     """
@@ -1032,8 +1029,8 @@ def getTraceFlow(vmanage, traceId, timestamp, state):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/traceFlow?traceId={traceId}&timestamp={timestamp}&state={state}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/nwpi/traceFlow?traceId={traceId}&timestamp={timestamp}&state={state}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getTraceHistory(vmanage):
     """
@@ -1047,8 +1044,8 @@ def getTraceHistory(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/nwpi/traceHistory"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/nwpi/traceHistory"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSession(vmanage, payload):
     """
@@ -1063,8 +1060,8 @@ def getSession(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/speed"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/stream/device/speed"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 def disableSpeedTestSession(vmanage, sessionId):
     """
@@ -1079,8 +1076,8 @@ def disableSpeedTestSession(vmanage, sessionId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/speed/disable/{sessionId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/speed/disable/{sessionId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getInterfaceBandwidth(vmanage, circuit, deviceUUID):
     """
@@ -1096,8 +1093,8 @@ def getInterfaceBandwidth(vmanage, circuit, deviceUUID):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/speed/interface/bandwidth?circuit={circuit}&deviceUUID={deviceUUID}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/speed/interface/bandwidth?circuit={circuit}&deviceUUID={deviceUUID}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def startSpeedTest(vmanage, sessionId):
     """
@@ -1112,8 +1109,8 @@ def startSpeedTest(vmanage, sessionId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/speed/start/{sessionId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/speed/start/{sessionId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSpeedTestStatus(vmanage, sessionId):
     """
@@ -1128,8 +1125,8 @@ def getSpeedTestStatus(vmanage, sessionId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/speed/status/{sessionId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/speed/status/{sessionId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def stopSpeedTest(vmanage, sessionId):
     """
@@ -1144,8 +1141,8 @@ def stopSpeedTest(vmanage, sessionId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/speed/stop/{sessionId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/speed/stop/{sessionId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def saveSpeedTestResults(vmanage, payload, deviceUUID, sessionId):
     """
@@ -1162,8 +1159,8 @@ def saveSpeedTestResults(vmanage, payload, deviceUUID, sessionId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/speed/{deviceUUID}/{sessionId}"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/stream/device/speed/{deviceUUID}/{sessionId}"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 def getSpeedTest(vmanage, sessionId, logId):
     """
@@ -1179,8 +1176,8 @@ def getSpeedTest(vmanage, sessionId, logId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/speed/{sessionId}?logId={logId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/stream/device/speed/{sessionId}?logId={logId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def processDeviceStatus(vmanage, payload, deviceUUID):
     """
@@ -1196,6 +1193,6 @@ def processDeviceStatus(vmanage, payload, deviceUUID):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/stream/device/status/{deviceUUID}"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/stream/device/status/{deviceUUID}"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
