@@ -22,4 +22,11 @@ class Vmanage(RestClient):
             self.headers['X-XSRF-TOKEN'] = res.text
             return True, "Authentication Successful."
         else:
-            return False, "Authentication Failed."
\ No newline at end of file
+            return False, "Authentication Failed."
+
+    def logout(self,):
+        res = self.session.get(f"{self.baseurl}/logout", headers=self.headers)
+        if res.status_code == 200:
+            return True, "Logout Successful"
+        else:
+            return False, "Logout Failed"
\ No newline at end of file
